@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval, Id
 
 
@@ -38,8 +38,7 @@ class ConfigurationSequence(metaclass=PoolMeta):
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=',
                 Id('sale_subscription', 'sequence_type_subscription')),
-            ],
-        depends=['company'])
+            ])
 
     @classmethod
     def default_subscription_sequence(cls):
