@@ -1,9 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.i18n import gettext
-from trytond.pool import PoolMeta, Pool
-
 from trytond.modules.party.exceptions import EraseError
+from trytond.pool import Pool, PoolMeta
 
 
 class Replace(metaclass=PoolMeta):
