@@ -1,6 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelSQL, ModelView, DeactivableMixin, fields
+from trytond.model import DeactivableMixin, ModelSQL, ModelView, fields
 from trytond.pyson import Eval
 
 
@@ -9,7 +9,7 @@ class Service(DeactivableMixin, ModelSQL, ModelView):
     __name__ = 'sale.subscription.service'
 
     product = fields.Many2One(
-        'product.product', "Product", required=True,
+        'product.product', "Product", required=True, ondelete='CASCADE',
         domain=[
             ('type', '=', 'service'),
             ])
@@ -18,8 +18,7 @@ class Service(DeactivableMixin, ModelSQL, ModelView):
     consumption_delay = fields.TimeDelta("Consumption Delay",
         states={
             'invisible': ~Eval('consumption_recurrence'),
-            },
-        depends=['consumption_recurrence'])
+            })
 
     def get_rec_name(self, name):
         return self.product.rec_name
