@@ -239,7 +239,7 @@ class Subscription(Workflow, ModelSQL, ModelView):
         company = pattern.get('company')
         if not company:
             company = cls.default_company()
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
     @classmethod
